==> f_k_chart-1.0.0.tar.gz: lib/flutter_k_chart/entity/k_line_entity.dart <==



import '../entity/k_entity.dart';

class KLineEntity extends KEntity {
  double open;
  double high;
  double low;
  double close;
  double vol;
  double amount;
  int count;
  int time;
  num seq; //序号

  KLineEntity({
    this.open,
    this.high,
    this.low,
    this.close,
    this.vol,
    this.amount,
    this.count,
    this.time,
    this.seq,
  });


  KLineEntity.fromJson2(Map<String, dynamic> json) {
    open = double.tryParse(json['open'])??0.0;
    high = double.tryParse(json['high'])??0.0;
    low = double.tryParse(json['low'])??0.0;
    close = double.tryParse(json['last'])??0.0;
    vol = 228929230.05960098;
    time =  int.tryParse(json['time'].toString());
    seq =  (json['seq'] as num)?.toInt() ?? 0;
  }

  KLineEntity.fromJson(Map<String, dynamic> json) {
    open = (json['open'] as num)?.toDouble();
    high = (json['high'] as num)?.toDouble();
    low = (json['low'] as num)?.toDouble();
    close = (json['close'] as num)?.toDouble();
    vol = (json['vol'] as num)?.toDouble();
    amount = (json['amount'] as num)?.toDouble();
    count = (json['count'] as num)?.toInt();
    time = (json['time'] as num)?.toInt();
    seq =  (json['seq'] as num)?.toInt();
  }

  Map<String, dynamic> toJson(){
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['time'] = this.time;
    data['open'] = this.open;
    data['close'] = this.close;
    data['high'] = this.high;
    data['low'] = this.low;
    data['vol'] = this.vol;
    data['amount'] = this.amount;
    data['count'] = this.count;
    data['seq'] = this.seq;
    return data;
  }

  @override
  String toString() {
    return 'KLineEntity{open: $open, high: $high, low: $low, close: $close, vol: $vol, time: $time, seq:$seq}';
  }

}

==> f_k_chart-1.7.0.tar.gz: lib/flutter_k_chart/entity/k_line_entity.dart <==
import '../entity/k_entity.dart';

class KLineEntity extends KEntity {
  double open;
  double high;
  double low;
  double close;
  double vol;
  double amount;
  int count;
  int time;
  num seq; //序号

  KLineEntity({
    this.open,
    this.high,
    this.low,
    this.close,
    this.vol,
    this.amount,
    this.count,
    this.time,
    this.seq,
  });


  KLineEntity.fromJson2(Map<String, dynamic> json) {
    open = double.tryParse(json['open'].toString())??0.0;
    high = double.tryParse(json['high'].toString())??0.0;
    low = double.tryParse(json['low'].toString())??0.0;
    close = double.tryParse(json['last'].toString())??0.0;
    vol = 228929230.05960098;
    time =  int.tryParse(json['time'].toString());
    seq =  (json['seq'] as num)?.toInt() ?? 0;
  }

  KLineEntity.fromJson(Map<String, dynamic> json) {
    open = (json['open'] as num)?.toDouble();
    high = (json['high'] as num)?.toDouble();
    low = (json['low'] as num)?.toDouble();
    close = (json['close'] as num)?.toDouble();
    vol = (json['vol'] as num)?.toDouble();
    amount = (json['amount'] as num)?.toDouble();
    count = (json['count'] as num)?.toInt();
    time = (json['time'] as num)?.toInt();
    seq =  (json['seq'] as num)?.toInt();
  }

  Map<String, dynamic> toJson(){
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['time'] = this.time;
    data['open'] = this.open;
    data['close'] = this.close;
    data['high'] = this.high;
    data['low'] = this.low;
    data['vol'] = this.vol;
    data['amount'] = this.amount;
    data['count'] = this.count;
    data['seq'] = this.seq;
    return data;
  }

  @override
  String toString() {
    return 'KLineEntity{open: $open, high: $high, low: $low, close: $close, vol: $vol, time: $time, seq:$seq}';
  }

}
